==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/TemplateCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TemplateCellInfoDescription } from "./TemplateCellInfoDescription";
/**
 * @hidden
 */
export let TemplateCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateCellInfoDescriptionMetadata.a == null) {
                TemplateCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateCellInfoDescriptionMetadata.c(TemplateCellInfoDescriptionMetadata.a);
            }
            if (a.j(TemplateCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(TemplateCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        }
        static d(a) {
            TemplateCellInfoDescriptionMetadata.b(a);
            a.aa("TemplateCellInfo", () => new TemplateCellInfoDescription());
            a.z("TemplateCellInfo", TemplateCellInfoDescriptionMetadata.a);
        }
    }
    TemplateCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateCellInfoDescriptionMetadata, 'TemplateCellInfoDescriptionMetadata');
    TemplateCellInfoDescriptionMetadata.a = null;
    return TemplateCellInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TemplateCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TemplateCellInfoDescription } from "./TemplateCellInfoDescription";
/**
 * @hidden
 */
export let TemplateCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateCellInfoDescriptionMetadata.a == null) {
                TemplateCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateCellInfoDescriptionMetadata.c(TemplateCellInfoDescriptionMetadata.a);
            }
            if (a.k(TemplateCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(TemplateCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        }
        static d(a) {
            TemplateCellInfoDescriptionMetadata.b(a);
            a.ac("TemplateCellInfo", () => new TemplateCellInfoDescription());
            a.ab("TemplateCellInfo", TemplateCellInfoDescriptionMetadata.a);
        }
    }
    TemplateCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateCellInfoDescriptionMetadata, 'TemplateCellInfoDescriptionMetadata');
    TemplateCellInfoDescriptionMetadata.a = null;
    return TemplateCellInfoDescriptionMetadata;
})();
